==> haskell-gitrev-1.3.1-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gitrev.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 gitrev
version:              1.3.1
visibility:           public
id:                   gitrev-1.3.1-FON4n1gHD3V19QnpFxKSVZ
key:                  gitrev-1.3.1-FON4n1gHD3V19QnpFxKSVZ
license:              BSD-3-Clause
maintainer:           acfoltzer@galois.com
author:               Adam C. Foltzer
homepage:             https://github.com/acfoltzer/gitrev
synopsis:             Compile git revision info into Haskell projects
description:
    Some handy Template Haskell splices for including the current git hash and branch in the code of your project. Useful for including in panic messages, @--version@ output, or diagnostic info for more informative bug reports.

category:             Development
abi:                  c10b537a611ce1d91c0c1c879489503f
exposed:              True
exposed-modules:      Development.GitRev
import-dirs:          /usr/lib/ghc-8.8.2/site-local/gitrev-1.3.1
library-dirs:         /usr/lib/ghc-8.8.2/site-local/gitrev-1.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.2/gitrev-1.3.1
hs-libraries:         HSgitrev-1.3.1-FON4n1gHD3V19QnpFxKSVZ
depends:
    base-4.13.0.0 base-compat-0.11.1-4oueEGUxmwHC6tuHqQ6hE2
    directory-1.3.4.0 filepath-1.4.2.1 process-1.6.7.0
    template-haskell-2.15.0.0

haddock-interfaces:   /usr/share/doc/haskell-gitrev/html/gitrev.haddock
haddock-html:         /usr/share/doc/haskell-gitrev/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-gitrev-1.3.1-19-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gitrev.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 gitrev
version:              1.3.1
visibility:           public
id:                   gitrev-1.3.1-9xc2mvA6hu5LA63NNYNNDI
key:                  gitrev-1.3.1-9xc2mvA6hu5LA63NNYNNDI
license:              BSD-3-Clause
maintainer:           acfoltzer@galois.com
author:               Adam C. Foltzer
homepage:             https://github.com/acfoltzer/gitrev
synopsis:             Compile git revision info into Haskell projects
description:
    Some handy Template Haskell splices for including the current git hash and branch in the code of your project. Useful for including in panic messages, @--version@ output, or diagnostic info for more informative bug reports.

category:             Development
abi:                  8807581892d41c0e9f9c5ac8abf880c5
exposed:              True
exposed-modules:      Development.GitRev
import-dirs:          /usr/lib/ghc-8.8.3/site-local/gitrev-1.3.1
library-dirs:         /usr/lib/ghc-8.8.3/site-local/gitrev-1.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/gitrev-1.3.1
hs-libraries:         HSgitrev-1.3.1-9xc2mvA6hu5LA63NNYNNDI
depends:
    base-4.13.0.0 base-compat-0.11.1-4oueEGUxmwHC6tuHqQ6hE2
    directory-1.3.6.0 filepath-1.4.2.1 process-1.6.8.0
    template-haskell-2.15.0.0

haddock-interfaces:   /usr/share/doc/haskell-gitrev/html/gitrev.haddock
haddock-html:         /usr/share/doc/haskell-gitrev/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
